Config API was replaced with capability APIs. Updated
doxygen documentation.

Signed-off-by: Petri Savolainen <[email protected]>
---
 include/odp/api/spec/packet.h    |  2 +-
 include/odp/api/spec/packet_io.h |  2 +-
 include/odp/api/spec/pool.h      | 14 +++++++++-----
 include/odp/api/spec/schedule.h  | 10 +++++-----
 4 files changed, 16 insertions(+), 12 deletions(-)

diff --git a/include/odp/api/spec/packet.h b/include/odp/api/spec/packet.h
index 481eee3..e9572b3 100644
--- a/include/odp/api/spec/packet.h
+++ b/include/odp/api/spec/packet.h
@@ -1015,7 +1015,7 @@ odp_pktio_t odp_packet_input(odp_packet_t pkt);
  *
  * @param pkt   Packet handle
  *
- * @return Packet interface index (0..odp_config_pktio_entries()-1)
+ * @return Packet interface index (0..odp_pktio_max_index())
  * @retval <0  Packet was not received on any interface
  */
 int odp_packet_input_index(odp_packet_t pkt);
diff --git a/include/odp/api/spec/packet_io.h b/include/odp/api/spec/packet_io.h
index 3e535d6..cacd498 100644
--- a/include/odp/api/spec/packet_io.h
+++ b/include/odp/api/spec/packet_io.h
@@ -923,7 +923,7 @@ int odp_pktio_headroom_set(odp_pktio_t pktio, uint32_t 
headroom);
  *
  * @param pktio   Packet I/O handle
  *
- * @return        Packet interface index (0..odp_config_pktio_entries()-1)
+ * @return        Packet interface index (0..odp_pktio_max_index())
  * @retval <0     On failure (e.g., handle not valid)
  */
 int odp_pktio_index(odp_pktio_t pktio);
diff --git a/include/odp/api/spec/schedule.h b/include/odp/api/spec/schedule.h
index a720e03..16d15d3 100644
--- a/include/odp/api/spec/schedule.h
+++ b/include/odp/api/spec/schedule.h
@@ -336,11 +336,11 @@ int odp_schedule_group_info(odp_schedule_group_t group,
  *
  * The number of ordered locks available is set by the lock_count parameter of
  * the schedule parameters passed to odp_queue_create(), which must be less
- * than or equal to the ODP_CONFIG_MAX_ORDERED_LOCKS_PER_QUEUE configuration
- * option. If this routine is called outside of an ordered context or with a
- * lock_index that exceeds the number of available ordered locks in this
- * context results are undefined. The number of ordered locks associated with
- * a given ordered queue may be queried by the odp_queue_lock_count() API.
+ * than or equal to queue capability 'max_ordered_locks'. If this routine is
+ * called outside of an ordered context or with a lock_index that exceeds the
+ * number of available ordered locks in this context results are undefined.
+ * The number of ordered locks associated with a given ordered queue may be
+ * queried by the odp_queue_lock_count() API.
  *
  * Each ordered lock may be used only once per ordered context. If events
  * are to be processed with multiple ordered critical sections, each should
diff --git a/include/odp/api/spec/pool.h b/include/odp/api/spec/pool.h
index cf4dd78..b31b6aa 100644
--- a/include/odp/api/spec/pool.h
+++ b/include/odp/api/spec/pool.h
@@ -180,23 +180,27 @@ typedef struct odp_pool_param_t {
                } buf;
                struct {
                        /** The number of packets that the pool must provide
-                           that are packet length 'len' bytes or smaller. */
+                           that are packet length 'len' bytes or smaller.
+                           The maximum value is defined by pool capability
+                           pkt.max_num. */
                        uint32_t num;
 
                        /** Minimum packet length that the pool must provide
                            'num' packets. The number of packets may be less
                            than 'num' when packets are larger than 'len'.
-                           Use 0 for default. */
+                           The maximum value is defined by pool capability
+                           pkt.max_len. Use 0 for default. */
                        uint32_t len;
 
                        /** Minimum number of packet data bytes that are stored
                            in the first segment of a packet. The maximum value
-                           is defined by ODP_CONFIG_PACKET_SEG_LEN_MAX.
+                           is defined by pool capability pkt.max_seg_len.
                            Use 0 for default. */
                        uint32_t seg_len;
 
-                       /** User area size in bytes. Specify as 0 if no user
-                           area is needed. */
+                       /** User area size in bytes. The maximum value is
+                           defined by pool capability pkt.max_uarea_size.
+                           Specify as 0 if no user area is needed. */
                        uint32_t uarea_size;
                } pkt;
                struct {
-- 
2.8.1

_______________________________________________
lng-odp mailing list
[email protected]
https://lists.linaro.org/mailman/listinfo/lng-odp

Reply via email to